# -*- coding: utf-8 -*-

# FOGLAMP_BEGIN
# See: http://fledge-iot.readthedocs.io/
# FOGLAMP_END

""" BucketService python client payload builder
"""

__author__ = "Amandeep Singh Arora"
__copyright__ = "Copyright (c) 2022 Dianomic Inc"
__license__ = "Apache 2.0"
__version__ = "${VERSION}"

from collections import OrderedDict
import json
import logging

from foglamp.common import logger

_LOGGER = logger.setup(__name__, level=logging.INFO)


class ModelQueryBuilder(object):
    """ Payload Builder to be used in Python client for Bucket Service

    """
    query_payload = None

    def __init__(self, initial_payload=OrderedDict()):
        self.__class__.query_payload = initial_payload if len(initial_payload) else OrderedDict()
        self.__class__.query_payload['attributes'] = {'type': 'model'}

    @classmethod
    def MATCH(cls, *args):
        """ Get the model files from the bucket service
            Args:
                args: List of tuples of type (<attribute name>, '=', <attribute value>)
            Returns:
                ModelQueryBuilder object with above args added to attribute list
            Raises:
        """

        _LOGGER.info("args={}".format(args))

        for arg in args:
            _LOGGER.info("arg={}. k={}, v={}".format(arg, arg[0], arg[2]))
            if arg[1] != '=':
                _LOGGER("ModelQueryBuilder(): MATCH: Unsupported operation {}".format(arg[1]))
            cls.query_payload['attributes'][arg[0]] = arg[2]

        return cls

    @classmethod
    def payload(cls):
        _LOGGER.info(" ModelQueryBuilder: cls.query_payload={}".format(cls.query_payload))
        s = json.dumps(cls.query_payload, sort_keys=False)
        _LOGGER.info(" ModelQueryBuilder: payload formed={}".format(s))
        return s
